==> fgarch_4022.89.orig.tar.gz: fGarch/README.md <==
<!-- badges: start -->
[![CRANStatusBadge](http://www.r-pkg.org/badges/version/fGarch)](https://cran.r-project.org/package=fGarch)
[![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/fGarch)](https://www.r-pkg.org/pkg/fGarch)
[![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/grand-total/fGarch?color=blue)](https://r-pkg.org/pkg/fGarch)
<!-- badges: end -->


Analyze and model heteroskedastic behavior in financial time series with GARCH, APARCH and
related models.

Package `fGarch` is part of the Rmetrics suite of R packages and is developed on R-forge at
[fGarch devel](https://r-forge.r-project.org/scm/viewvc.php/pkg/fGarch/?root=rmetrics).
The root of Rmetrics is at [R-forge](https://r-forge.r-project.org/projects/rmetrics).


# Installing fGarch


Install the [latest stable version](https://cran.r-project.org/package=fGarch) of
`fGarch` from CRAN:

    install.packages("fGarch")


You can install the
[development version](https://r-forge.r-project.org/scm/viewvc.php/pkg/fGarch/?root=rmetrics)
of `fGarch` from R-forge:

    install.packages("fGarch", repos = "http://R-Forge.R-project.org")

To report bugs visit [Rmetrics](https://r-forge.r-project.org/projects/rmetrics/).

# Documentation

You can view the documentation of `fGarch` at
[fGarchDoc](https://geobosh.github.io/fGarchDoc/)
or download the
[reference manual](https://cran.r-project.org/package=fGarch/fGarch.pdf)
of the latest release from CRAN.

A comprehensive overview of the models and conditional distributions employed in package
`fGarch`, along with worked examples, is available in the following paper by the original
authors of the package:

[WurtzEtAlGarch.pdf](https://github.com/GeoBosh/fGarchDoc/blob/master/WurtzEtAlGarch.pdf).

(*This is an unpublished manuscript. Some online sources, confusingly, attribute it to JSS,
vol 55, issue 2, but this seems to have taken the placeholders `VV` and `II` in the heading
on the first page as being the Roman numbers 55 and 2.*)

==> fgarch_4052.93.orig.tar.gz: fGarch/README.md <==
<!-- badges: start -->
[![CRANStatusBadge](http://www.r-pkg.org/badges/version/fGarch)](https://cran.r-project.org/package=fGarch)
[![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/fGarch)](https://www.r-pkg.org/pkg/fGarch)
[![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/grand-total/fGarch?color=blue)](https://r-pkg.org/pkg/fGarch)
<!-- badges: end -->


Analyze and model heteroskedastic behavior in financial time series with GARCH, APARCH and
related models.

Package `fGarch` is part of the Rmetrics suite of R packages and is developed on R-forge at
[fGarch devel](https://r-forge.r-project.org/scm/viewvc.php/pkg/fGarch/?root=rmetrics).
The root of Rmetrics is at [R-forge](https://r-forge.r-project.org/projects/rmetrics).


# Installing fGarch


Install the [latest stable version](https://cran.r-project.org/package=fGarch) of
`fGarch` from CRAN:

    install.packages("fGarch")


You can install the
[development version](https://r-forge.r-project.org/scm/viewvc.php/pkg/fGarch/?root=rmetrics)
of `fGarch` from R-forge:

    install.packages("fGarch", repos = "http://R-Forge.R-project.org")

To report bugs visit [Rmetrics](https://r-forge.r-project.org/projects/rmetrics/).

# Documentation

You can view the documentation of `fGarch` at
[fGarchDoc](https://geobosh.github.io/fGarchDoc/) (rendered with pkgdown)
or download the
[reference manual](https://cran.r-project.org/package=fGarch/fGarch.pdf)
of the latest release from CRAN.

A comprehensive overview of the models and conditional distributions employed in package
`fGarch`, along with worked examples, is available in the following paper by the original
authors of the package:

[WurtzEtAlGarch.pdf](https://github.com/GeoBosh/fGarchDoc/blob/master/WurtzEtAlGarch.pdf).

(*This is an unpublished manuscript. Some online sources, confusingly, attribute it to JSS,
vol 55, issue 2, but this seems to have taken the placeholders `VV` and `II` in the heading
on the first page as being the Roman numbers 55 and 2.*)
